@@ -28,7 +28,18 @@ class PLASMANM_EDITOR_EXPORT WifiSecurity : public SettingWidget
 public:
     // Keep this in sync with NetworkManager::WirelessSecurityType from
     // NetworkManagerQt.
-    enum SecurityTypeIndex { None = 0, WepHex, WepPassphrase, Leap, DynamicWep, WpaPsk, WpaEap, SAE, Wpa3SuiteB192, OWE };
+    enum SecurityTypeIndex {
+        None = 0,
+        WepHex,
+        WepPassphrase,
+        Leap,
+        DynamicWep,
+        WpaPsk,
+        WpaEap,
+        SAE,
+        Wpa3SuiteB192,
+        OWE
+    };
 
     explicit WifiSecurity(const NetworkManager::Setting::Ptr &setting = NetworkManager::Setting::Ptr(),
                           const NetworkManager::Security8021xSetting::Ptr &setting8021x = NetworkManager::Security8021xSetting::Ptr(),
