@@ -7,11 +7,16 @@
 #ifndef PLASMA_NM_APPLET_PROXY_MODEL_H
 #define PLASMA_NM_APPLET_PROXY_MODEL_H
 
+#include "plasmanm_internal_export.h"
+
 #include <QSortFilterProxyModel>
 
-class Q_DECL_EXPORT AppletProxyModel : public QSortFilterProxyModel
+#include <qqmlregistration.h>
+
+class PLASMANM_INTERNAL_EXPORT AppletProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
+    QML_ELEMENT
     Q_PROPERTY(QAbstractItemModel *sourceModel READ sourceModel WRITE setSourceModel)
 public:
     explicit AppletProxyModel(QObject *parent = nullptr);
