@@ -19,14 +19,11 @@ class Q_DECL_EXPORT OpenconnectUiPlugin : public VpnUiPlugin
 public:
     explicit OpenconnectUiPlugin(QObject *parent = nullptr, const QVariantList & = QVariantList());
     ~OpenconnectUiPlugin() override;
-    SettingWidget *widget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr) override;
-    SettingWidget *askUser(const NetworkManager::VpnSetting::Ptr &setting, const QStringList &hints, QWidget *parent = nullptr) override;
+    SettingWidget *widget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent) override;
+    SettingWidget *askUser(const NetworkManager::VpnSetting::Ptr &setting, const QStringList &hints, QWidget *parent) override;
 
     QString suggestedFileName(const NetworkManager::ConnectionSettings::Ptr &connection) const override;
-    QString supportedFileExtensions() const override;
     QMessageBox::StandardButtons suggestedAuthDialogButtons() const override;
-    NMVariantMapMap importConnectionSettings(const QString &fileName) override;
-    bool exportConnectionSettings(const NetworkManager::ConnectionSettings::Ptr &connection, const QString &fileName) override;
 };
 
 #endif //  OPENCONNECT_UI_H
